# Short submission period (R003)

The submission period is too short.

The submission period starts with contracting documents being available to potential suppliers and ends with the submission deadline for expressions of interest or bids.

## Methodology

For each contracting process, the **submission period** is calculated as $(/tender/tenderPeriod/endDate - /tender/tenderPeriod/startDate)$ in whole days.

A contracting process is flagged if the submission period is shorter than the **threshold** of 15 whole days.

:::{admonition} Example
:class: seealso

The National Rail Service publishes a tender notice on March 15 with a submission deadline of March 20.
:::

:::{admonition} Why is this a red flag?
:class: hint

A corrupt buyer can give the pre-determined bidder an unfair advantage by privately informing the pre-determined bidder of the opportunity in advance, and by giving other bidders less time to prepare competitive bids.
:::

<small>Based on "Shortened time span for bidding process" in [*Corruption in Public Procurement: Finding the Right Indicators*](https://www.researchgate.net/publication/303359108_Corruption_in_Public_Procurement_Finding_the_Right_Indicators), "Short submission period" in [*An Objective Corruption Risk Index Using Public Procurement Data*](https://www.researchgate.net/publication/301646354_An_Objective_Corruption_Risk_Index_Using_Public_Procurement_Data), "Short or inadequate notice to bidders" in [*Guide to Combating Corruption & Fraud in Infrastructure Development Projects*](https://guide.iacrc.org/red-flag-short-or-inadequate-notice-to-bidders/), and "Deadline for submitting bids is very short" in [*Fraud in Public Procurement: A collection of Red Flags and Best Practices*](https://ec.europa.eu/sfc/system/files/documents/sfc-files/fraud-public-procurement-final-20122017-ares20176254403.pdf).</small>

## Output

The indicator's value is always 1.0.

## Configuration

All configuration is optional.

To override the default **threshold**, add to your settings file, as a natural number:

```ini
[R003]
threshold = 15 # default
```

To set the **threshold** per procurement method details (`/tender/procurementMethodDetails`), add a `[R003.procurement_method_details]` section to your settings file, in which the property name is a `/tender/procurementMethodDetails` value, and the property value is a natural number. For example, you can assign the minimum periods per legislation:

```ini
[R003.procurement_method_details]
Cotización = 7
Licitación = 10
Licitación de Seguros = 10
```

To calculate this indicator for some procurement methods only (`/tender/procurementMethod`), add to your settings file, as a pipe-separated list, for example:

```ini
[R003]
procurement_methods = open|selective|limited
```

## Demonstration

*Input*

:::{literalinclude} ../../../examples/R/003.jsonl
:language: json
:::

*Output*

```console
$ ocdscardinal indicators --settings docs/examples/settings.ini --no-meta docs/examples/R/003.jsonl
{"OCID":{"F":{"R003":1.0}}}

```
